import { ComponentFixture, TestBed, fakeAsync, tick } from '@angular/core/testing';
import { HttpResponse } from '@angular/common/http';
import { FormBuilder } from '@angular/forms';
import { of } from 'rxjs';

import { GitsearchTestModule } from '../../../test.module';
import { SavedSearchesUpdateComponent } from 'app/entities/saved-searches/saved-searches-update.component';
import { SavedSearchesService } from 'app/entities/saved-searches/saved-searches.service';
import { SavedSearches } from 'app/shared/model/saved-searches.model';

describe('Component Tests', () => {
  describe('SavedSearches Management Update Component', () => {
    let comp: SavedSearchesUpdateComponent;
    let fixture: ComponentFixture<SavedSearchesUpdateComponent>;
    let service: SavedSearchesService;

    beforeEach(() => {
      TestBed.configureTestingModule({
        imports: [GitsearchTestModule],
        declarations: [SavedSearchesUpdateComponent],
        providers: [FormBuilder],
      })
        .overrideTemplate(SavedSearchesUpdateComponent, '')
        .compileComponents();

      fixture = TestBed.createComponent(SavedSearchesUpdateComponent);
      comp = fixture.componentInstance;
      service = fixture.debugElement.injector.get(SavedSearchesService);
    });

    describe('save', () => {
      it('Should call update service on save for existing entity', fakeAsync(() => {
        // GIVEN
        const entity = new SavedSearches(123);
        spyOn(service, 'update').and.returnValue(of(new HttpResponse({ body: entity })));
        comp.updateForm(entity);
        // WHEN
        comp.save();
        tick(); // simulate async

        // THEN
        expect(service.update).toHaveBeenCalledWith(entity);
        expect(comp.isSaving).toEqual(false);
      }));

      it('Should call create service on save for new entity', fakeAsync(() => {
        // GIVEN
        const entity = new SavedSearches();
        spyOn(service, 'create').and.returnValue(of(new HttpResponse({ body: entity })));
        comp.updateForm(entity);
        // WHEN
        comp.save();
        tick(); // simulate async

        // THEN
        expect(service.create).toHaveBeenCalledWith(entity);
        expect(comp.isSaving).toEqual(false);
      }));
    });
  });
});
